@@ -2,6 +2,7 @@
 
 #include "retro-cairo-display.h"
 
+#include "retro-pixbuf.h"
 #include "retro-pixdata.h"
 
 struct _RetroCairoDisplay
@@ -312,11 +313,16 @@ retro_cairo_display_get_pixbuf (RetroCairoDisplay *self)
  * @pixbuf: a #GdkPixbuf
  *
  * Sets @pixbuf as the currently displayed video frame.
+ *
+ * retro_pixbuf_set_aspect_ratio() can be used to specify the aspect ratio for
+ * the pixbuf. Otherwise the core's aspect ratio will be used.
  */
 void
 retro_cairo_display_set_pixbuf (RetroCairoDisplay *self,
                                 GdkPixbuf         *pixbuf)
 {
+  gfloat aspect_ratio;
+
   g_return_if_fail (self != NULL);
 
   if (self->pixbuf == pixbuf)
@@ -327,6 +333,10 @@ retro_cairo_display_set_pixbuf (RetroCairoDisplay *self,
   if (pixbuf != NULL)
     self->pixbuf = g_object_ref (pixbuf);
 
+  aspect_ratio = retro_pixbuf_get_aspect_ratio (pixbuf);
+  if (aspect_ratio != 0.f)
+    self->aspect_ratio = aspect_ratio;
+
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_PIXBUF]);
 }
 
